<?php

/**
 * This configuration will be read and overlaid on top of the
 * default configuration. Command line arguments will be applied
 * after this file is read.
 */
return [
    // Supported values: '7.0', '7.1', '7.2', null.
    // If this is set to null,
    // then Phan assumes the PHP version which is closest to the minor version
    // of the php executable used to execute phan.
    // TODO: Set this.
    'target_php_version' => '7.1',

    // VERY expensive, but very needed before upgrading to new php versions.
    // Disabled for the defacto config.
    'backward_compatibility_checks' => false,

    // A list of directories that should be parsed for class and
    // method information. After excluding the directories
    // defined in exclude_analysis_directory_list, the remaining
    // files will be statically analyzed for errors.
    //
    // Thus, both first-party and third-party code being used by
    // your application should be included in this list.
    'directory_list' => [
        '.'
    ],

    // Because of how we use some functions, like healthCheck, false-positives can happen, so disabling.
    'dead_code_detection' => false,

    // If true, check to make sure the return type declared
    // in the doc-block (if any) matches the return type
    // declared in the method signature.
    'check_docblock_signature_return_type_match' => true,

    // If true, check to make sure the param types declared
    // in the doc-block (if any) matches the param types
    // declared in the method signature.
    'check_docblock_signature_param_type_match' => true,

    // A directory list that defines files that will be excluded
    // from static analysis, but whose class and method
    // information should be included.
    //
    // Generally, you'll want to include the directories for
    // third-party code (such as "vendor/") in this list.
    //
    // n.b.: If you'd like to parse but not analyze 3rd
    //       party code, directories containing that code
    //       should be added to both the `directory_list`
    //       and `exclude_analysis_directory_list` arrays.
    "exclude_analysis_directory_list" => [
        'vendor/'
    ],

    // A file list that defines files that will be excluded
        // from parsing and analysis and will not be read at all.
        //
        // This is useful for excluding hopelessly unanalyzable
        // files that can't be removed for whatever reason.
    'exclude_file_list' => [
        'app/Console/Kernel.php',   // Iffy Lumen source that is not Skunkware
        'bootstrap/app.php',        // Lumen file, that we can fix another day.
        'routes/web.php'            // We should analyse this soon, but inflection is troublesome.
    ],

    // This should almost always never have anything in it, unless a good reason is agreed on.
    'suppress_issue_types' => [
        'PhanTypeMismatchReturn'        // This is sad, but Lumen's JsonResponse does not extend Response. @todo: fix
    ],

    // A list of plugin files to execute.
    'plugins' => [
        'AlwaysReturnPlugin',  // can also be written as 'vendor/phan/phan/.phan/plugins/AlwaysReturnPlugin.php'
        'UnreachableCodePlugin',
        'DollarDollarPlugin',
        'DuplicateArrayKeyPlugin',
        'PregRegexCheckerPlugin',
        'PrintfCheckerPlugin',
        'NumericalComparisonPlugin' // loose == comparison must be done for numeric and strict === for non-numeric
    ],
];
