<?php

namespace App\Exceptions;

use Exception;
use Illuminate\Validation\ValidationException;
use Illuminate\Auth\Access\AuthorizationException;
use Illuminate\Database\Eloquent\ModelNotFoundException;
use Laravel\Lumen\Exceptions\Handler as ExceptionHandler;
use Symfony\Component\HttpKernel\Exception\HttpException;
use Illuminate\Http\Response;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

class Handler extends ExceptionHandler
{
    /**
     * A list of the exception types that should not be reported.
     *
     * @var array
     */
    protected $dontReport = [
        AuthorizationException::class,
        HttpException::class,
        ModelNotFoundException::class,
        ValidationException::class,
    ];

    /**
     * Report or log an exception.
     *
     * This is a great spot to send exceptions to Sentry, Bugsnag, etc.
     *
     * @param  \Exception  $exception
     * @return void
     */
    public function report(Exception $exception)
    {
        parent::report($exception);
    }

    /**
     * Render an exception into an HTTP response.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \Exception  $exception
     * @return \Illuminate\Http\Response
     */
    public function render($request, Exception $exception)
    {
        $trace = [];
        if (getenv("APP_ENV") == 'dev') {
            $trace[0] = get_class($e);
            $trace[] = $e->getMessage();
            $trace[] = $e->getTraceAsString();
        }
        if ($e instanceof NotFoundHttpException) {
            $responseArray = (getenv("APP_ENV") == 'dev') ? [
                "Call" => "Invalid({$_SERVER['REQUEST_URI']})",
                "Trace" => $trace
                ] : [];
            return response()->json(
                $responseArray,
                404
            );
        } elseif ($e instanceof ValidationException) {
            return parent::render($request, $e);
        } else {
            $responseArray = (getenv("APP_ENV") == 'dev') ? [
            "Call" => $_SERVER['REQUEST_URI'],
            "Trace" => $trace
            ] : [];
            return response()->json(
                $responseArray,
                500
            );
        }
    }
}
